-- import "Turbine.Debug";
import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";
-- import "Turbine.UI.Extensions";
-- import "Turbine.Utils";

FilterBagOptionsWindow = class(Turbine.UI.Lotro.Window);

function FilterBagOptionsWindow:Constructor()
	Turbine.UI.Lotro.Window.Constructor(self);

	-- load the last settings saved
	glob_loading = false;
	self:LoadSettings();

	--[[ set window properties ]]--
	local w = 310;
	local h = 190;
	self:SetSize(w, h);
	self:SetBackColor(Turbine.UI.Color(0, 0, 0, 0));
	if not self.settings.positionX then
	  self.settings.positionX=self.settings.posx+20;
	  self.settings.positionY=self.settings.posy-60;
	end
	self:SetPosition(self.settings.positionX, self.settings.positionY);
	self:SetOpacity(1);
	self:SetText("FilterBag Options");
	self:SetAllowDrop(false);
	self:SetZOrder(100);

	self.focusBgColor = Turbine.UI.Color(0.3, 0.5, 0.5, 0.5);

	local margin = 20;
	local y = 35;

	-- Build the UI
	self.clickActionLbl = Betsiel.FilterBag.UI.Label();
	self.clickActionLbl:SetParent(self);
	self.clickActionLbl:SetSize(120, 40);
	self.clickActionLbl:SetPosition(margin, y);
	self.clickActionLbl:SetText("which Bag(s)\n to sort:");
	self.clickActionLbl:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight);
	self.clickActionCombo = Betsiel.FilterBag.UI.ComboBox();
	self.clickActionCombo:SetParent(self);
	self.clickActionCombo:SetSize(120, 20);
	self.clickActionCombo:SetPosition(165, y);
	self.clickActionCombo:AddItem("All", 0);
	self.clickActionCombo:AddItem("1st", 1);
	self.clickActionCombo:AddItem("2nd", 2);
	self.clickActionCombo:AddItem("3rd", 3);
	self.clickActionCombo:AddItem("4th", 4);
	self.clickActionCombo:AddItem("5th", 5);
  if self.settings.sortb == 1 and self.settings.sorte > 15 then
	self.clickActionCombo:SetSelection(0);
  else
	self.clickActionCombo:SetSelection(self.settings.sorte/15);
  end
	self.clickActionCombo.SelectedIndexChanged = function(sender, args)
		self:SaveSettings();
	end
	y = y + 40;

	self.barOrientationLbl = Betsiel.FilterBag.UI.Label();
	self.barOrientationLbl:SetParent(self);
	self.barOrientationLbl:SetSize(120, 20);
	self.barOrientationLbl:SetPosition(margin, y);
	self.barOrientationLbl:SetText("Sort order:");
	self.barOrientationLbl:SetTextAlignment(Turbine.UI.ContentAlignment.MiddleRight);
	self.barOrientationCombo = Betsiel.FilterBag.UI.ComboBox();
	self.barOrientationCombo:SetParent(self);
	self.barOrientationCombo:SetSize(140, 20);
	self.barOrientationCombo:SetPosition(145, y);
	self.barOrientationCombo:AddItem("forward", 1);
	self.barOrientationCombo:AddItem("reversed", 7);
	self.barOrientationCombo:SetSelection(self.settings.sort);
	self.barOrientationCombo.SelectedIndexChanged = function(sender, args)
		self:SaveSettings();
	end
	y = y + 30;

	self.autoShowBarCB = Betsiel.FilterBag.UI.CheckBox();
	self.autoShowBarCB:SetCheckBoxLocation(Betsiel.FilterBag.UI.CheckBox.LocationLeft);
	self.autoShowBarCB:SetParent(self);
	self.autoShowBarCB:SetText("make background transparent");
	self.autoShowBarCB:SetPosition(margin, y);
	if self.settings.trans == 1 then
		self.autoShowBarCB:SetChecked(true);
	else
		self.autoShowBarCB:SetChecked(false);
	end
	self.autoShowBarCB:SetSize(w - margin * 2, 20);
	self.autoShowBarCB.Click = function(sender, args)
		self:SaveSettings();
	end
	y = y + 25;

	_plugins = Turbine.PluginManager.GetAvailablePlugins();
	local ver = "1.6c";
--	ver = plugin:GetVersion();
	local apartments = {}
	for i,plug in pairs(_plugins) do
--	  apartments[plug.Name] = plug.ScriptState;
	  if plug.Name == "FilterBag" then
	    ver = plug.Version;
	  elseif plug.Name == "AltInventory" then
--	    Turbine.Shell.WriteLine(plug.Name)
--	    apartments[plug.Name] = true;
	    altinv = plug;
	  end
	end
	if debugging then 
	  Turbine.PluginData.Save(Turbine.DataScope.Character, "plugins", _plugins);
	end
	self.altinv = Betsiel.FilterBag.UI.CheckBox();
	self.altinv:SetCheckBoxLocation(Betsiel.FilterBag.UI.CheckBox.LocationRight);
	self.altinv:SetParent(self);
	self.altinv:SetText("load alts inventory");
	self.altinv:SetPosition(margin, y);
	self.altinv:SetChecked(false);
	self.altinv:SetSize(w - margin * 2, 20);
	self.altinv.Click = function(sender, args)
	  self:SaveSettings();
	  if self.altinv:IsChecked() then
	    Turbine.PluginManager.LoadPlugin("AltInventory");
	    if pcall( Turbine.Gameplay.LocalPlayer.GetInstance ) then
		altinv:Activate(true);
	    end
	  else
	    Turbine.PluginManager.UnloadScriptState("AltInventory");
	    Turbine.Shell.WriteLine("unloading AltInventory")
	    Turbine.UI.Lotro.LotroUI.Reset()
	    if pcall( Turbine.Gameplay.LocalPlayer.GetInstance ) then
		altinv:Activate(false);
	    end
	  end
	end
	y = y + 25;

	self.version = Betsiel.FilterBag.UI.Label();
	self.version:SetParent(self);
	self.version:SetSize(260, 20);
	self.version:SetPosition(margin, y);
	self.version:SetText("FilterBag " .. ver .. " by Alexey & Betsiel");

	self:LoadSettings();

	self.Closing = function(sender, args)
		local curX, curY = self:GetPosition();
		self.settings.positionX = curX;
		self.settings.positionY = curY;
		self:SaveSettings();
	end
end

function FilterBagOptionsWindow:GetClickAction()
	return self.clickActionCombo:GetSelection();
end

function FilterBagOptionsWindow:GetBarOrientation()
	return self.barOrientationCombo:GetSelection();
end

function FilterBagOptionsWindow:GetOpac()
 local trans = 1;
 if self.settings and self.settings.trans then trans = self.settings.trans;
 elseif glob_settings and glob_settings.trans then trans = glob_settings.trans;
 else
  glob_loading = true;
  self.settings = Turbine.PluginData.Load( Turbine.DataScope.Character , "filterbag");
  glob_loading = false;
  if self.settings and self.settings.trans then trans = self.settings.trans; end
 end

  return trans;
end

function FilterBagOptionsWindow:LoadSettings()
	-- load the settings.  If a value is not available, set a default value
	glob_loading = true;
	self.loading = true;

  self.settings = Turbine.PluginData.Load( Turbine.DataScope.Character , "filterbag");

	if (type(self.settings) ~= "table") then
		self.settings = {};
	end

	if (not self.settings.sizex) then
	  if (glob_settings.sizex) then
		self.settings.sizex = glob_settings.sizex;
		self.settings.sizey = glob_settings.sizey;
	  else
		self.settings.sizex = 410;
		self.settings.sizey = 305;
	  end
	end
	if (not self.settings.posx) then
	  if (glob_settings.posx) then
		self.settings.posx = glob_settings.posx;
		self.settings.posy = glob_settings.posy;
	  else
		self.settings.posx = Turbine.UI.Display.GetWidth() - 500;
		self.settings.posy = Turbine.UI.Display.GetHeight() - 400;
	  end
	end

	if (not self.settings.trans) then
	  if (glob_settings.trans) then
		self.settings.trans = glob_settings.trans;
	  else
	    self.settings.trans = 1;
	  end
	end
    if not self.settings.sortb then
	  if (glob_settings.sortb) then
		self.settings.sortb = glob_settings.sortb;
		self.settings.sorte = glob_settings.sorte;
	  else
		self.settings.sortb = 1;
		self.settings.sorte = 75;
	  end
    end
    if not self.settings.sort then
	  if (glob_settings.sort) then
		self.settings.sort = glob_settings.sort;
	  else self.settings.sort = 1; end
    end

	glob_loading = false;
	self.loading = false;
end

function FilterBagOptionsWindow:SaveSettings()
	if (self.loading) then
		return;
	end

	if (self.autoShowBarCB:IsChecked() == true) then
	    self.settings.trans = 1;
	else
	    self.settings.trans = 4;
	end
	local bags = self.clickActionCombo:GetSelection();
	if bags == 1 then
	  self.settings.sortb = 1;
	  self.settings.sorte = 15;
	elseif bags == 2 then
	  self.settings.sortb = 16;
	  self.settings.sorte = 30;
	elseif bags == 3 then
	  self.settings.sortb = 31;
	  self.settings.sorte = 45;
	elseif bags == 4 then
	  self.settings.sortb = 46;
	  self.settings.sorte = 60;
	elseif bags == 5 then
	  self.settings.sortb = 61;
	  self.settings.sorte = 75;
	else
	  self.settings.sortb = 1;
	  self.settings.sorte = 75;
	end

	self.settings.sort = self.barOrientationCombo:GetSelection();

	-- save the settings
  glob_loading = true;
    if glob_settings.sizex then self.settings.sizex = glob_settings.sizex
    else glob_settings.sizex = self.settings.sizex end
    if glob_settings.sizey then self.settings.sizey = glob_settings.sizey
    else glob_settings.sizey = self.settings.sizey end
    if glob_settings.posx then self.settings.posx = glob_settings.posx
    else glob_settings.posx = self.settings.posx end
    if glob_settings.posy then self.settings.posy = glob_settings.posy
    else glob_settings.posy = self.settings.posy end
    glob_settings.sortb = self.settings.sortb;
    glob_settings.sorte = self.settings.sorte;
    glob_settings.sort = self.settings.sort;
    glob_settings.trans = self.settings.trans;
    glob_settings.positionX=self.settings.positionX;
    glob_settings.positionY=self.settings.positionY;
  Turbine.PluginData.Save(Turbine.DataScope.Character, "filterbag", glob_settings);
  glob_loading = false;

end
